@@ -1,34 +1,36 @@
 from .imports import *
 
+def get_user_pass_host_key(**kwargs):
+    args = ['password','user_at_host','host','key','user']
+    values,kwargs = get_from_kwargs(*args,**kwargs,del_kwarg=False)
+    return values
 
 # --- Base remote checker -----------------------------------------------------
-def _remote_test(path: str, test_flag: str, user_at_host: str, timeout: int = 5) -> bool:
+def _remote_test(path: str, test_flag: str, timeout: int = 5,*args, **kwargs) -> bool:
     """
     Run a remote shell test (e.g. -f, -d) via SSH.
     Returns True if test succeeds, False otherwise.
     """
-    cmd = f"[ {test_flag} {shlex.quote(path)} ] && echo 1 || echo 0"
     try:
-        result = subprocess.check_output(
-            ["ssh", user_at_host, cmd],
-            stderr=subprocess.DEVNULL,
-            text=True,
-            timeout=timeout
-        ).strip()
-        return result == "1"
+        kwargs['cmd']=f"[ {test_flag} {shlex.quote(path)} ] && echo 1 || echo 0"
+        kwargs['text']=True
+        kwargs['timeout']=timeout
+        kwargs['stderr']=subprocess.DEVNULL
+        result = run_pruned_func(run_cmd,**kwargs)
+        return result.strip() == "1"
     except Exception:
         return False
 
 
 # --- Individual path checks --------------------------------------------------
-def is_remote_file(path: str, user_at_host: str) -> bool:
+def is_remote_file(path: str,*args, **kwargs) -> bool:
     """True if remote path is a file."""
-    return _remote_test(path, "-f", user_at_host)
+    return _remote_test(path, "-f", **kwargs)
 
 
-def is_remote_dir(path: str, user_at_host: str) -> bool:
+def is_remote_dir(path: str,*args, **kwargs) -> bool:
     """True if remote path is a directory."""
-    return _remote_test(path, "-d", user_at_host)
+    return _remote_test(path, "-d", **kwargs)
 
 
 def is_local_file(path: str) -> bool:
@@ -42,33 +44,40 @@ def is_local_dir(path: str) -> bool:
 
 
 # --- Unified interface -------------------------------------------------------
-def is_file(path: str,*args, user_at_host: Optional[str] = None,**kwargs) -> bool:
+
+def is_file(path: str,*args,**kwargs) -> bool:
     """Determine if path is a file (works local or remote)."""
-    if user_at_host:
-        return is_remote_file(path, user_at_host)
+    if get_user_pass_host_key(**kwargs):
+        return is_remote_file(path, **kwargs)
     return is_local_file(path)
 
 
-def is_dir(path: str, *args,user_at_host: Optional[str] = None,**kwargs) -> bool:
+def is_dir(path: str, *args,**kwargs) -> bool:
     """Determine if path is a directory (works local or remote)."""
-    if user_at_host:
-        return is_remote_dir(path, user_at_host)
+    if get_user_pass_host_key(**kwargs):
+        return is_remote_dir(path, **kwargs)
     return is_local_dir(path)
 
-
+def is_exists(path: str, *args,**kwargs) -> bool:
+    if is_file(path,**kwargs):
+        return True
+    if is_dir(path,**kwargs):
+        return True
+    return False
 # --- Optional: keep your original all-in-one wrapper ------------------------
 def check_path_type(
     path: str,
-    user_at_host: Optional[str] = None,
+    *args,
+    **kwargs
 ) -> str:
     """
     Return 'file', 'directory', 'missing', or 'unknown'.
     Uses isolated is_file/is_dir functions.
     """
-    if user_at_host:
-        if is_remote_file(path, user_at_host):
+    if get_user_pass_host_key(**kwargs):
+        if is_remote_file(path,**kwargs):
             return "file"
-        elif is_remote_dir(path, user_at_host):
+        elif is_remote_dir(path,**kwargs):
             return "directory"
         else:
             return "missing"
